==> dsda-doom_0.25.6+dfsg.orig.tar.xz: dsda-doom-0.25.6/prboom2/src/dsda/hud_components.h <==
//
// Copyright(C) 2022 by Ryan Krafnick
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// DESCRIPTION:
//	DSDA HUD Components
//

#include "hud_components/ammo_text.h"
#include "hud_components/armor_text.h"
#include "hud_components/attempts.h"
#include "hud_components/big_ammo.h"
#include "hud_components/big_armor.h"
#include "hud_components/big_armor_text.h"
#include "hud_components/big_artifact.h"
#include "hud_components/big_health.h"
#include "hud_components/big_health_text.h"
#include "hud_components/command_display.h"
#include "hud_components/composite_time.h"
#include "hud_components/coordinate_display.h"
#include "hud_components/event_split.h"
#include "hud_components/fps.h"
#include "hud_components/health_text.h"
#include "hud_components/keys.h"
#include "hud_components/level_splits.h"
#include "hud_components/line_display.h"
#include "hud_components/local_time.h"
#include "hud_components/ready_ammo_text.h"
#include "hud_components/render_stats.h"
#include "hud_components/speed_text.h"
#include "hud_components/stat_totals.h"
#include "hud_components/tracker.h"
#include "hud_components/weapon_text.h"

==> dsda-doom_0.27.5+dfsg.orig.tar.xz: dsda-doom-0.27.5/prboom2/src/dsda/hud_components.h <==
//
// Copyright(C) 2022 by Ryan Krafnick
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// DESCRIPTION:
//	DSDA HUD Components
//

#include "hud_components/ammo_text.h"
#include "hud_components/armor_text.h"
#include "hud_components/attempts.h"
#include "hud_components/big_ammo.h"
#include "hud_components/big_armor.h"
#include "hud_components/big_armor_text.h"
#include "hud_components/big_artifact.h"
#include "hud_components/big_health.h"
#include "hud_components/big_health_text.h"
#include "hud_components/color_test.h"
#include "hud_components/command_display.h"
#include "hud_components/composite_time.h"
#include "hud_components/coordinate_display.h"
#include "hud_components/event_split.h"
#include "hud_components/fps.h"
#include "hud_components/free_text.h"
#include "hud_components/health_text.h"
#include "hud_components/keys.h"
#include "hud_components/level_splits.h"
#include "hud_components/line_display.h"
#include "hud_components/local_time.h"
#include "hud_components/map_coordinates.h"
#include "hud_components/map_time.h"
#include "hud_components/map_title.h"
#include "hud_components/map_totals.h"
#include "hud_components/message.h"
#include "hud_components/minimap.h"
#include "hud_components/ready_ammo_text.h"
#include "hud_components/render_stats.h"
#include "hud_components/secret_message.h"
#include "hud_components/speed_text.h"
#include "hud_components/stat_totals.h"
#include "hud_components/tracker.h"
#include "hud_components/weapon_text.h"
